@@ -9,12 +9,18 @@ class MediaReader:
     """
     An all around media reader built on top of opencv.
 
-
     === Example Usage ===
     media = MediaReader("video.mp4")
     for frame in media.read():
         # do something
     media.close()
+
+    === Input ===
+    source: "webcam" or str or int
+        media source.
+        - "webcam": access default webcam, or specify the webcam integer id as in opencv.
+        - int: webcam integer id as in opencv
+        - str: image or video filepath, or rtsp url
     """
     def __init__(self, source="webcam"):
         self.input_type, self.cam = self._parse_source(source)
@@ -24,7 +30,7 @@ class MediaReader:
         _ext = lambda source: splitext(source)[-1]
         source = 0 if source == "webcam" else source
 
-        if source == 0:
+        if isinstance(source, int) or source.startswith("rtsp://"):
             input_type = "camera"
             cam = cv2.VideoCapture(source)
         elif _ext(source) in [".mp4", ".avi"]:
@@ -61,20 +67,33 @@ class MediaReader:
         if self.input_type == "image":
             return self.cam
         else:
-            return self._video_reader()
+            while True:
+                cam_on, frame = self.cam.read()
+                if cam_on:
+                    yield frame
+                else:
+                    break
+
+    def capture(self):
+        if self.input_type != "image":
+            return next(iter(self.read()))
+
+    def stream(self, transform=None):
+        while True:
+            cam_on, frame = self.cam.read()
+            if cam_on:
+                if transform is not None:
+                    frame = transform(frame)
+                success, frame = cv2.imencode(".jpg", frame)
+                yield b'--frame\r\n' \
+                      b'Content-Type: image/jpeg\r\n\r\n' + frame.tobytes() + b'\r\n\r\n'
+            else:
+                break
 
     def close(self):
         if self.input_type in ['video', "camera"]:
             self.cam.release()
 
-    def _video_reader(self):
-        while True:
-            cam_on, frame = self.cam.read()
-            if cam_on:
-                yield frame
-            else:
-                break
-
     def to_array(self, mode="rgb"):
         if self.input_type == "video":
             frames = [frame for frame in self.read()]
