@@ -42,4 +42,7 @@ def denorm_landmark(frame, box, points, to_int=True):
 
 
 def denorm_pixel(frame):
-    return (frame * 255).astype(np.uint8)
+    if frame.dtype in [np.float32, np.float64]:
+        return (frame * 255).astype(np.uint8)
+    else:
+        return frame
